@@ -96,12 +96,12 @@ typedef struct _MoveEventData MoveEventData;
 enum
 {
   PROP_0,
+  PROP_DEFAULT_CALENDAR,
   PROP_SETTINGS,
 };
 
 enum
 {
-  SOURCE_ACTIVATED,
   SOURCE_ADDED,
   SOURCE_CHANGED,
   SOURCE_REMOVED,
@@ -274,10 +274,20 @@ gather_events (ECalDataModel         *data_model,
                time_t                 instance_end,
                gpointer               user_data)
 {
-  GList **result = user_data;
   GcalEvent *event;
+  GError *error;
+  GList **result;
 
-  event = gcal_event_new (e_client_get_source (E_CLIENT (client)), comp);
+  error = NULL;
+  result = user_data;
+  event = gcal_event_new (e_client_get_source (E_CLIENT (client)), comp, &error);
+
+  if (error)
+    {
+      g_warning ("Error: %s", error->message);
+      g_clear_error (&error);
+      return TRUE;
+    }
 
   *result = g_list_append (*result, event);/* FIXME: add me sorted */
 
@@ -415,7 +425,7 @@ on_client_readonly_changed (EClient    *client,
 
   unit = g_hash_table_lookup (manager->clients, source);
   if (unit && unit->enabled)
-    g_signal_emit (GCAL_MANAGER (user_data), signals[SOURCE_ACTIVATED], 0, source, !e_client_is_readonly (client));
+    source_changed (manager, source);
 }
 
 
@@ -461,7 +471,11 @@ on_event_created (GObject      *source_object,
       g_warning ("Error creating object: %s", error->message);
       g_error_free (error);
     }
-  g_debug ("Event: %s created successfully", new_uid);
+  else
+    {
+      gcal_manager_set_default_source (data->manager, gcal_event_get_source (data->event));
+      g_debug ("Event: %s created successfully", new_uid);
+    }
 
   g_free (new_uid);
   free_async_ops_data (data);
@@ -698,13 +712,24 @@ source_get_last_credentials_required_arguments_cb (GObject      *source_object,
 static void
 gcal_manager_class_init (GcalManagerClass *klass)
 {
-  G_OBJECT_CLASS (klass)->constructed = gcal_manager_constructed;
-  G_OBJECT_CLASS (klass)->finalize = gcal_manager_finalize;
-  G_OBJECT_CLASS (klass)->set_property = gcal_manager_set_property;
-  G_OBJECT_CLASS (klass)->get_property = gcal_manager_get_property;
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+  object_class->finalize = gcal_manager_finalize;
+  object_class->constructed = gcal_manager_constructed;
+  object_class->set_property = gcal_manager_set_property;
+  object_class->get_property = gcal_manager_get_property;
 
   /* properties */
-  g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_SETTINGS,
+  g_object_class_install_property (object_class,
+                                   PROP_DEFAULT_CALENDAR,
+                                   g_param_spec_object ("default-calendar",
+                                                        "Default calendar",
+                                                        "The default calendar",
+                                                        E_TYPE_SOURCE,
+                                                        G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class,
+                                   PROP_SETTINGS,
                                    g_param_spec_object ("settings",
                                                         "Application settings",
                                                         "The settings of the application passed down from GcalApplication",
@@ -712,11 +737,6 @@ gcal_manager_class_init (GcalManagerClass *klass)
                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
 
   /* signals */
-  signals[SOURCE_ACTIVATED] = g_signal_new ("source-activated", GCAL_TYPE_MANAGER, G_SIGNAL_RUN_LAST,
-                                           0,
-                                           NULL, NULL, NULL,
-                                           G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_BOOLEAN);
-
   signals[SOURCE_ADDED] = g_signal_new ("source-added", GCAL_TYPE_MANAGER, G_SIGNAL_RUN_LAST,
                                         0,
                                         NULL, NULL, NULL,
@@ -815,6 +835,12 @@ gcal_manager_constructed (GObject *object)
       return;
     }
 
+  g_object_bind_property (manager->source_registry,
+                          "default-calendar",
+                          manager,
+                          "default-calendar",
+                          G_BINDING_DEFAULT);
+
   manager->credentials_prompter = e_credentials_prompter_new (manager->source_registry);
 
   /* First disable credentials prompt for all but calendar sources... */
@@ -921,6 +947,22 @@ gcal_manager_set_property (GObject      *object,
 
   switch (property_id)
     {
+    case PROP_DEFAULT_CALENDAR:
+        {
+          ESource *source;
+
+          source = e_source_registry_ref_default_calendar (self->source_registry);
+          g_object_unref (source);
+
+          /* Only notify a change when they're different, otherwise we'll end up in a notify loop */
+          if (g_value_get_object (value) == source)
+            break;
+
+          e_source_registry_set_default_calendar (self->source_registry, g_value_get_object (value));
+          g_object_notify (object, "default-calendar");
+        }
+      break;
+
     case PROP_SETTINGS:
       if (g_set_object (&self->settings, g_value_get_object (value)))
         g_object_notify (object, "settings");
@@ -941,6 +983,10 @@ gcal_manager_get_property (GObject    *object,
 
   switch (property_id)
     {
+    case PROP_DEFAULT_CALENDAR:
+      g_value_take_object (value, e_source_registry_ref_default_calendar (self->source_registry));
+      break;
+
     case PROP_SETTINGS:
       g_value_set_object (value, self->settings);
       return;
