@@ -342,7 +342,7 @@ make_row_for_event (GcalSearchView *view,
   g_free (text);
 
   /* show 'all day' instead of 00:00 */
-  if (gcal_event_get_all_day (event))
+  if (!gcal_event_get_all_day (event))
     {
       text = g_date_time_format (local_datetime, view->format_24h ? "%R" : "%r");
       time_label = gtk_label_new (text);
@@ -570,22 +570,24 @@ gcal_search_view_component_added (ECalDataModelSubscriber *subscriber,
                                   ECalComponent           *comp)
 {
   GcalSearchView *view;
-  ECalComponentDateTime dt;
 
   RowEventData *row_data;
   GcalEvent *event;
+  GError *error;
   gchar *uid;
 
   view = GCAL_SEARCH_VIEW (subscriber);
-
-  e_cal_component_get_dtstart (comp, &dt);
-
-  /* Protect against NULL start date */
-  if (dt.value == NULL)
-    return;
+  error = NULL;
 
   /* event */
-  event = gcal_event_new (e_client_get_source (E_CLIENT (client)), comp);
+  event = gcal_event_new (e_client_get_source (E_CLIENT (client)), comp, &error);
+
+  if (error)
+    {
+      g_warning ("Error creating event: %s", error->message);
+      g_clear_error (&error);
+      return;
+    }
 
   /* insert row_data at the hash of events */
   row_data = g_new0 (RowEventData, 1);
@@ -605,8 +607,6 @@ gcal_search_view_component_added (ECalDataModelSubscriber *subscriber,
   view->num_results++;
 
   update_view (GCAL_SEARCH_VIEW (subscriber));
-
-  e_cal_component_free_datetime (&dt);
 }
 
 static void
