@@ -1061,7 +1061,7 @@ create_event_detailed_cb (GcalView *view,
   GcalEvent *event;
 
   comp = build_component_from_details ("", start_span, end_span);
-  event = gcal_event_new (gcal_manager_get_default_source (window->manager), comp);
+  event = gcal_event_new (gcal_manager_get_default_source (window->manager), comp, NULL);
 
   gcal_edit_dialog_set_event_is_new (GCAL_EDIT_DIALOG (window->edit_dialog), TRUE);
   gcal_edit_dialog_set_event (GCAL_EDIT_DIALOG (window->edit_dialog), event);
@@ -1389,6 +1389,7 @@ gcal_window_constructed (GObject *object)
   helper_settings = g_settings_new ("org.gnome.desktop.interface");
   clock_format = g_settings_get_string (helper_settings, "clock-format");
   use_24h_format = (g_strcmp0 (clock_format, "24h") == 0);
+  g_message ("%s: %s", G_STRFUNC, clock_format);
   g_free (clock_format);
   g_object_unref (helper_settings);
 
@@ -1426,6 +1427,8 @@ gcal_window_constructed (GObject *object)
   gcal_search_view_connect (GCAL_SEARCH_VIEW (window->search_view), window->manager);
   gcal_search_view_set_time_format (GCAL_SEARCH_VIEW (window->search_view), use_24h_format);
 
+  g_message ("%s: %d", G_STRFUNC, use_24h_format);
+
   /* refresh timeout, first is fast */
   window->refresh_timeout_id = g_timeout_add (FAST_REFRESH_TIMEOUT, (GSourceFunc) refresh_sources, object);
 
